@@ -3,7 +3,7 @@ from germanium.test_cases.client import ClientTestCase
 from germanium.tools.http import assert_http_ok, assert_http_redirect
 from germanium.tools import assert_true, assert_false, assert_in
 
-from auth_token.models import Token
+from auth_token.models import AuthorizationToken
 
 from .base import BaseTestCaseMixin
 
@@ -26,8 +26,8 @@ class AdminLoginISCoreTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_http_redirect(resp)
         assert_http_ok(self.get(self.INDEX_URL))
         assert_in('Authorization', self.c.cookies)
-        assert_false(Token.objects.last().allowed_header)
-        assert_true(Token.objects.last().allowed_cookie)
+        assert_false(AuthorizationToken.objects.last().allowed_header)
+        assert_true(AuthorizationToken.objects.last().allowed_cookie)
         assert_http_ok(self.get(self.LOGOUT_URL))
         assert_http_redirect(self.get(self.INDEX_URL))
 
